@@ -17,6 +17,7 @@
 #include <KDBusService>
 #include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
+#include <KQuickAddons/QtQuickSettings>
 
 #include "Configuration.h"
 #include "ToolsModel.h"
@@ -49,10 +50,6 @@ public:
     {
         m_pageId = parser.value("page-id");
         m_pageName = parser.value("page-name");
-
-        if (m_pageId.isEmpty() && m_pageName.isEmpty()) {
-            m_pageId = QStringLiteral("overview.page");
-        }
     }
 
     QVariant aboutData() const
@@ -96,6 +93,7 @@ int main(int argc, char **argv)
 
     aboutData.setTranslator(i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"), i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
 
+    aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?product=plasma-systemmonitor");
     KAboutData::setApplicationData(aboutData);
 
     KDBusService service(KDBusService::Unique);
@@ -114,10 +112,10 @@ int main(int argc, char **argv)
         return new CommandLineArguments{parser};
     });
 
+    KQuickAddons::QtQuickSettings::init();
+
     QQmlApplicationEngine engine;
-
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-
     engine.load(QStringLiteral(":/main.qml"));
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, []() {
